@@ -15,6 +15,19 @@ else:
 
 
 class ScreenBrightnessError(Exception):
+    '''
+    Generic error class designed to make catching errors under one umbrella easy.
+    Raised when the brightness cannot be set/retrieved.
+
+    Example:
+        ```python
+        import screen_brightness_control as sbc
+        try:
+            sbc.set_brightness(50)
+        except sbc.ScreenBrightnessError as error:
+            print(error)
+        ```
+    '''
     def __init__(self, message="Cannot set/retrieve brightness level"):
         self.message = message
         super().__init__(self.message)
@@ -304,19 +317,6 @@ def flatten_list(thick_list: List[Any]) -> List[Any]:
         ```
     '''
     flat_list = []
-    '''
-    Generic error class designed to make catching errors under one umbrella easy.
-    Raised when the brightness cannot be set/retrieved.
-
-    Example:
-        ```python
-        import screen_brightness_control as sbc
-        try:
-            sbc.set_brightness(50)
-        except sbc.ScreenBrightnessError as error:
-            print(error)
-        ```
-    '''
     for item in thick_list:
         if isinstance(item, list):
             flat_list += flatten_list(item)
@@ -349,25 +349,25 @@ def logarithmic_range(start: int, stop: int, step: int = 1) -> Generator[int, No
     stop = int(min(100, stop))
 
     if start == stop or abs(stop - start) <= 1:
-        return stop
+        yield start
+    else:
+        value_range = stop - start
 
-    value_range = stop - start
+        last_yielded = None
+        for x in range(start, stop + 1, step):
+            # get difference from base point
+            x -= start
+            # calculate progress through our range as a percentage
+            x = (x / value_range) * 100
+            # convert along logarithmic curve (inverse of y = 50log(x)) to another percentage
+            x = 10 ** (x / 50)
+            # apply this percentage to our range and add back starting offset
+            x = int(((x / 100) * value_range) + start)
 
-    last_yielded = None
-    for x in range(start, stop + 1, step):
-        # get difference from base point
-        x -= start
-        # calculate progress through our range as a percentage
-        x = (x / value_range) * 100
-        # convert along logarithmic curve (inverse of y = 50log(x)) to another percentage
-        x = 10 ** (x / 50)
-        # apply this percentage to our range and add back starting offset
-        x = int(((x / 100) * value_range) + start)
-
-        if x == last_yielded:
-            continue
-        yield x
-        last_yielded = x
+            if x == last_yielded:
+                continue
+            yield x
+            last_yielded = x
 
 
 def check_output(command: list, max_tries: int = 1):
